Struct rustc_ap_rustc_span::symbol::SymbolStr [−][src]
pub struct SymbolStr { /* fields omitted */ }Expand description
An alternative to Symbol, useful when the chars within the symbol need to
be accessed. It deliberately has limited functionality and should only be
used for temporary values.
Because the interner outlives any thread which uses this type, we can
safely treat string which points to interner data, as an immortal string,
as long as this type never crosses between threads.